JsonPreprocessor package — The Json Preprocessor documentation

# JsonPreprocessor package

## Module contents

class CJsonPreprocessor.CJsonPreprocessor(syntax='json', currentCfg={})

  Bases: `object`

  CJsonPreprocessor helps to handle configuration file as json format:

    - Allow comment within json file

    - Allow import json file within json file

  jsonLoad(jFile, masterFile=True)

    Method: jsonLoad loads the json file then parses to dict object

    Args:

      jFile: string, json file input

    Returns:

      oJson: dict

class CJsonPreprocessor.CPythonJSONDecoder(*args, **kwargs)

  Bases: `json.decoder.JSONDecoder`

  Add below python values when scanning json data

  True | True
  False | False
  None | None

  custom_scan_once(string, idx)

class CJsonPreprocessor.CSyntaxType

  Bases: `object`

  json = 'json'
  python = 'python'